==> org.eclipse.php.core.source_8.3.0.202405251527.jar: org/eclipse/php/internal/core/facet/PHPFacetsConstants.java <==
/*******************************************************************************
 * Copyright (c) 2012-2018 IBM Corporation and others.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     Zend Technologies
 *     Martin Eisengardt <martin.eisengardt@fiducia.de>
 *******************************************************************************/
package org.eclipse.php.internal.core.facet;

public class PHPFacetsConstants {

	public static final String PHP_CORE_COMPONENT = "php.core.component"; //$NON-NLS-1$
	public static final String PHP_COMPONENT = "php.component"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_5 = "5"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_5_3 = "5.3"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_5_4 = "5.4"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_5_5 = "5.5"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_5_6 = "5.6"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_7 = "7"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_7_1 = "7.1"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_7_2 = "7.2"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_7_3 = "7.3"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_7_4 = "7.4"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_8_0 = "8.0"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_8_1 = "8.1"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_8_2 = "8.2"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_8_3 = "8.3"; //$NON-NLS-1$
}

==> org.eclipse.php.core.source_8.4.0.202512011310.jar: org/eclipse/php/internal/core/facet/PHPFacetsConstants.java <==
/*******************************************************************************
 * Copyright (c) 2012-2018 IBM Corporation and others.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     Zend Technologies
 *     Martin Eisengardt <martin.eisengardt@fiducia.de>
 *******************************************************************************/
package org.eclipse.php.internal.core.facet;

public class PHPFacetsConstants {

	public static final String PHP_CORE_COMPONENT = "php.core.component"; //$NON-NLS-1$
	public static final String PHP_COMPONENT = "php.component"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_5 = "5"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_5_3 = "5.3"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_5_4 = "5.4"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_5_5 = "5.5"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_5_6 = "5.6"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_7 = "7"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_7_1 = "7.1"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_7_2 = "7.2"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_7_3 = "7.3"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_7_4 = "7.4"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_8_0 = "8.0"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_8_1 = "8.1"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_8_2 = "8.2"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_8_3 = "8.3"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_8_4 = "8.4"; //$NON-NLS-1$
	public static final String PHP_COMPONENT_VERSION_8_5 = "8.5"; //$NON-NLS-1$
}
